==> openstack-swift-1.7.2-sources.jar: org/jclouds/openstack/swift/v1/functions/EntriesWithoutMetaPrefix.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jclouds.openstack.swift.v1.functions;

import java.util.Map;
import java.util.Map.Entry;

import com.google.common.base.Function;
import com.google.common.collect.ImmutableMap;
import com.google.common.collect.Multimap;

/**
 * Extracts entries whose keys start with {@code .*-Meta-}.
 * 
 * @param from
 *           a {@link Multimap} containing the prefixed headers.
 * 
 * @return the extracted metadata without the prefixed keys. 
 */
enum EntriesWithoutMetaPrefix implements Function<Multimap<String, String>, Map<String, String>> {
   INSTANCE;

   @Override
   public Map<String, String> apply(Multimap<String, String> arg0) {
      ImmutableMap.Builder<String, String> metadata = ImmutableMap.builder();
      for (Entry<String, String> header : arg0.entries()) {
         int index = header.getKey().indexOf("-Meta-");
         if (index != -1) {
            metadata.put(header.getKey().substring(index + 6), header.getValue());
         }
      }
      return metadata.build();
   }
}

==> openstack-swift-2.7.0-sources.jar: org/jclouds/openstack/swift/v1/functions/EntriesWithoutMetaPrefix.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jclouds.openstack.swift.v1.functions;

import java.util.Map;
import java.util.Map.Entry;

import com.google.common.base.Function;
import com.google.common.collect.ImmutableMap;
import com.google.common.collect.Multimap;

/**
 * Extracts entries whose keys start with {@code .*-Meta-}.
 * 
 * @param from
 *           a {@link Multimap} containing the prefixed headers.
 * 
 * @return the extracted metadata without the prefixed keys. 
 */
public enum EntriesWithoutMetaPrefix implements Function<Multimap<String, String>, Map<String, String>> {
   INSTANCE;

   @Override
   public Map<String, String> apply(Multimap<String, String> arg0) {
      ImmutableMap.Builder<String, String> metadata = ImmutableMap.builder();
      for (Entry<String, String> header : arg0.entries()) {
         int index = header.getKey().toLowerCase().indexOf("-meta-");
         if (index != -1) {
            metadata.put(header.getKey().substring(index + 6), header.getValue());
         }
      }
      return metadata.build();
   }
}
